@@ -25,7 +25,7 @@
 
 class AddNewStreamImpl : public AddNewStream
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
