@@ -34,7 +34,7 @@ class ProcessListViewItem;
 
 class ProcessController : public TQObject
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	ProcessController(ProcessListViewItem * parent);
