@@ -30,7 +30,7 @@ class ProcessController;
 
 class ProcessListViewItem : public TQObject, public TQListViewItem
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
   
